@@ -21,6 +21,7 @@
 #define ZM_MPEG_H
 
 #include "zm_ffmpeg.h"
+#include <pthread.h>
 
 #if HAVE_LIBAVCODEC
 
@@ -41,11 +42,11 @@ protected:
   const char *format;
   const char *codec_name;
   enum _AVPIXELFORMAT pf;
-  AVOutputFormat *of;
+  const AVOutputFormat *of;
   AVFormatContext *ofc;
   AVStream *ost;
   AVCodecContext *codec_context;
-  AVCodec *codec;
+  const AVCodec *codec;
   AVFrame *opicture;
   AVFrame *tmp_opicture;
   uint8_t *video_outbuf;
